summaryrefslogtreecommitdiffstats
path: root/krita/plugins/paintops/defaultpaintops/kis_penop.cc
diff options
context:
space:
mode:
Diffstat (limited to 'krita/plugins/paintops/defaultpaintops/kis_penop.cc')
-rw-r--r--krita/plugins/paintops/defaultpaintops/kis_penop.cc26
1 files changed, 13 insertions, 13 deletions
diff --git a/krita/plugins/paintops/defaultpaintops/kis_penop.cc b/krita/plugins/paintops/defaultpaintops/kis_penop.cc
index d93a75d4..0fcbca02 100644
--- a/krita/plugins/paintops/defaultpaintops/kis_penop.cc
+++ b/krita/plugins/paintops/defaultpaintops/kis_penop.cc
@@ -21,7 +21,7 @@
*/
-#include <qrect.h>
+#include <tqrect.h>
#include <kdebug.h>
@@ -70,8 +70,8 @@ void KisPenOp::paintAt(const KisPoint &pos, const KisPaintInformation& info)
KisPoint hotSpot = brush->hotSpot(info);
KisPoint pt = pos - hotSpot;
- Q_INT32 x = pt.roundX();
- Q_INT32 y = pt.roundY();
+ TQ_INT32 x = pt.roundX();
+ TQ_INT32 y = pt.roundY();
KisPaintDeviceSP dab = 0;
if (brush->brushType() == IMAGE ||
@@ -79,14 +79,14 @@ void KisPenOp::paintAt(const KisPoint &pos, const KisPaintInformation& info)
dab = brush->image(device->colorSpace(), info);
}
else {
- // Compute mask without sub-pixel positioning
- KisAlphaMaskSP mask = brush->mask(info);
- dab = computeDab(mask);
+ // Compute tqmask without sub-pixel positioning
+ KisAlphaMaskSP tqmask = brush->tqmask(info);
+ dab = computeDab(tqmask);
}
m_painter->setPressure(info.pressure);
- QRect dabRect = QRect(0, 0, brush->maskWidth(info), brush->maskHeight(info));
- QRect dstRect = QRect(x, y, dabRect.width(), dabRect.height());
+ TQRect dabRect = TQRect(0, 0, brush->tqmaskWidth(info), brush->tqmaskHeight(info));
+ TQRect dstRect = TQRect(x, y, dabRect.width(), dabRect.height());
KisImage * image = device->image();
@@ -104,7 +104,7 @@ void KisPenOp::paintAt(const KisPoint &pos, const KisPaintInformation& info)
KisRectIteratorPixel pixelIt = dab->createRectIterator(dabRect.x(), dabRect.y(), dabRect.width(), dabRect.height(), true);
while (!pixelIt.isDone()) {
- Q_UINT8 alpha = cs->getAlpha(pixelIt.rawData());
+ TQ_UINT8 alpha = cs->getAlpha(pixelIt.rawData());
if (alpha < (4 * OPACITY_OPAQUE) / 10) {
cs->setAlpha(pixelIt.rawData(), OPACITY_TRANSPARENT, 1);
@@ -115,10 +115,10 @@ void KisPenOp::paintAt(const KisPoint &pos, const KisPaintInformation& info)
++pixelIt;
}
- Q_INT32 sx = dstRect.x() - x;
- Q_INT32 sy = dstRect.y() - y;
- Q_INT32 sw = dstRect.width();
- Q_INT32 sh = dstRect.height();
+ TQ_INT32 sx = dstRect.x() - x;
+ TQ_INT32 sy = dstRect.y() - y;
+ TQ_INT32 sw = dstRect.width();
+ TQ_INT32 sh = dstRect.height();
if (m_source->hasSelection()) {
m_painter->bltSelection(dstRect.x(), dstRect.y(), m_painter->compositeOp(), dab.data(),